pub enum JsonPacketResponse {
    Join {
        size: Option<usize>,
    },
    Create {
        id: String,
    },
    Leave {
        index: usize,
    },
    Error {
        message: String,
    },
}
Represents a response to a JsonPacket packet.

This enum is used to represent different types of responses to a JsonPacket packet.

Variants



Join

Fields

size: Option<usize>

The number of existing users in the room. This field is None if the room is empty.

A response to a Join packet.

This variant is used to indicate the result of a Join packet. The size field is used to specify the number of existing users in the room.



Create

Fields

id: String

The id of the created room.

A response to a Create packet.

This variant is used to indicate the result of a Create packet. The id field is used to specify the room id.



Leave

Fields

index: usize

The index of the user who left the room.

A response to a Leave packet.

This variant is used to indicate the result of a Leave packet. The index field is used to specify the index of the user who left the room.



Error

Fields

message: String

The error message.

An error response.

This variant is used to indicate an error. The message field is used to specify the error message.