Enum caesar_core::shared::JsonPacketResponse
source · pub enum JsonPacketResponse {
Join {
size: Option<usize>,
},
Create {
id: String,
},
Leave {
index: usize,
},
Error {
message: String,
},
}Expand description
Represents a response to a JsonPacket packet.
This enum is used to represent different types of responses to a JsonPacket packet.
Variants
Join
Fields
A response to a Join packet.
This variant is used to indicate the result of a Join packet. The size field is used to specify the number of existing users in the room.
Create
A response to a Create packet.
This variant is used to indicate the result of a Create packet. The id field is used to specify the room id.
Leave
A response to a Leave packet.
This variant is used to indicate the result of a Leave packet. The index field is used to specify the index of the user who left the room.
Error
An error response.
This variant is used to indicate an error. The message field is used to specify the error message.